class I2C():
	def __init__(self, smbus):
		"""
		Wrapper class for the smbus
		:param smbus: the smbus to send and receive data from smbus.SMBus(1)
		"""
		self.bus = smbus

	def write_to(self, address, offset, value):
		self.bus.write_byte_data(address, offset, value)

	def read_from(self, address, offset):
		value = self.bus.read_byte_data(address, offset)
		return value

	def read(self, address):
		return self.bus.read_byte(address)

	def scan(self):
		devices = list()
		for address in range(255):
			try:
				self.bus.read_byte(address) #try to read byte
				devices.append(address)
			except:  # exception if read_byte fails
				pass
		return devices


from setuptools import setup, find_packages

setup(
    name='mcp23017',
    version='1.1.0',
    description='MCP23017 Library',
    long_description=open("README.md", 'r').read(),
    long_description_content_type='text/markdown',
    author='Mirko Haeberlin',
    author_email='mirko.haeberlin@open-things.de',
    url='https://github.com/open-thngs/MCP23017-python',
    packages=['mcp23017',],
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
    python_requires='>=3.6',
)
